@@ -1,11 +1,8 @@
-from pdb import set_trace
-import pkg_resources
-
 from .write.writer_nc import write_nc_legacy
 from .config import get_config
 from . import config, parse, write
 
-__version__ = pkg_resources.get_distribution("linc").version
+__version__ = "3.0.5"
 
 __all__ = [
     "write_nc_legacy",
@@ -13,4 +10,4 @@ __all__ = [
     "parse",
     "write",
     "config",
-]
\ No newline at end of file
+]
