@@ -1,6 +1,5 @@
 import numpy as np
 import pandas as pd
-import numpy.typing as npt
 
 from linc.utils import device_id_to_str
 
@@ -12,15 +11,16 @@ def parse_dataset(dataset: bytes, header: Header) -> pd.DataFrame:
     dt = dt.newbyteorder("<")
 
     max_length = max(map(lambda x: x.bins, header.channels))
-    parsed = np.full((len(header.channels), max_length), fill_value=np.nan)
     _parsed = pd.DataFrame()
 
     for channel in header.channels:
         bytes_size = channel.bins * 4
         current_array = np.frombuffer(dataset, dtype=dt, count=channel.bins)
+        # Use u
         _parsed[device_id_to_str(channel.device_id)] = np.pad(
             current_array, (0, max_length - current_array.shape[0]), "empty"
         )
+
         # parsed[idx, : current_array.shape[0]] = current_array
 
         *_, dataset = dataset[bytes_size:].partition(b"\r\n")
@@ -28,6 +28,9 @@ def parse_dataset(dataset: bytes, header: Header) -> pd.DataFrame:
         # print(parsed)
         # print(before, symbol)
 
-    # set_trace()
+    # WARNING: Do not erase the following line unless you know what you are doing
+    _parsed = (
+        _parsed / 1.0
+    )  # Necesary to force all data to have float64 instead of uint32
 
     return _parsed
