@@ -1,4 +1,3 @@
-import pkg_resources
 from typing import TypeVar, Iterator
 
 from .models import DeviceId, MeasurementTypeEnum
@@ -20,9 +19,9 @@ def split_seq(seq: list[T], sep: T) -> Iterator[list[T]]:
             break
 
 
-def safe_get_list(l: list[U], idx: int, default: U | None) -> U | None:
+def safe_get_list(list_input: list[U], idx: int, default: U | None) -> U | None:
     try:
-        return l[idx]
+        return list_input[idx]
     except IndexError:
         return default
 
@@ -42,5 +41,14 @@ def to_acquisition_type_string(type: MeasurementTypeEnum) -> str:
 
 
 def device_id_to_str(device_id: DeviceId) -> str:
-    return f"{device_id.type}{device_id.number}"
+    return f"{device_id.type.value}{device_id.number}"
 
+
+def str_to_device_id(device_id: str) -> DeviceId:
+    sep_index = 3 if device_id.startswith("S2") else 2
+
+    # set_trace()
+    return DeviceId(
+        type=device_id[:sep_index],  # type: ignore
+        number=device_id[sep_index:],  # type: ignore
+    )
