@@ -4,14 +4,13 @@ from ..utils import device_id_to_str, safe_get_list, to_acquisition_type_string
 
 
 def compare_joinable_dataset(header1: Header, header2: Header) -> None:
-    assert (
-        header1.channels == header2.channels
-    ), "While parsing a same dataset, channels most remain identical"
-
-    assert (
-        header1.location == header2.location
-    ), "While parsing a same dataset, channels most remain identical"
+    assert header1.channels == header2.channels, (
+        "While parsing a same dataset, channels most remain identical"
+    )
 
+    assert header1.location == header2.location, (
+        "While parsing a same dataset, channels most remain identical"
+    )
 
 
 def get_merged_channel_config(channel: Channel, config: Config) -> Channel:
@@ -25,7 +24,7 @@ def get_merged_channel_config(channel: Channel, config: Config) -> Channel:
     if channel_config is None:
         return channel
 
-    return Channel(**channel.copy(update=channel_config).dict())  # type: ignore
+    return Channel(**channel.model_copy(update=channel_config).model_dump_())  # type: ignore
 
 
 def format_channel(channel: Channel, format: str) -> str:
